==> azure-core-1.8.1-sources.jar: com/azure/core/exception/ResourceModifiedException.java <==
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.

package com.azure.core.exception;

import com.azure.core.http.HttpResponse;

/**
 * The exception thrown for invalid resource modification with status code of 4XX, typically 409 Conflict.
 */
public class ResourceModifiedException extends HttpResponseException {

    /**
     * Initializes a new instance of the ResourceModifiedException class.
     *
     * @param message the exception message or the response content if a message is not available
     * @param response the HTTP response
     */
    public ResourceModifiedException(final String message, final HttpResponse response) {
        super(message, response);
    }

    /**
     * Initializes a new instance of the ResourceModifiedException class.
     *
     * @param message the exception message or the response content if a message is not available
     * @param response the HTTP response
     * @param value the deserialized response value
     */
    public ResourceModifiedException(final String message, final HttpResponse response, final Object value) {
        super(message, response, value);
    }

    /**
     * Initializes a new instance of the ResourceModifiedException class.
     *
     * @param message the exception message or the response content if a message is not available
     * @param response the HTTP response
     * @param cause the Throwable which caused the creation of this ResourceModifiedException
     */
    public ResourceModifiedException(final String message, final HttpResponse response, final Throwable cause) {
        super(message, response, cause);
    }
}

==> azure-core-1.56.1-sources.jar: com/azure/core/exception/ResourceModifiedException.java <==
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.

package com.azure.core.exception;

import com.azure.core.http.HttpResponse;

/**
 * <p>The {@code ResourceModifiedException} represents an exception thrown when an HTTP request attempts to modify a
 * resource in a way that is not allowed.</p>
 *
 * <p>This exception is typically thrown when the service responds with a status code of 4XX, typically 409 Conflict.
 * This can occur when trying to modify a resource that has been updated by another process, resulting in a conflict.</p>
 *
 * <p>This class also provides methods to get the {@link HttpResponse} that was received when the exception occurred and
 * the deserialized HTTP response value.</p>
 *
 * @see com.azure.core.exception
 * @see com.azure.core.exception.HttpResponseException
 * @see com.azure.core.http.HttpResponse
 */
public class ResourceModifiedException extends HttpResponseException {

    /**
     * Initializes a new instance of the ResourceModifiedException class.
     *
     * @param message the exception message or the response content if a message is not available
     * @param response the HTTP response
     */
    public ResourceModifiedException(final String message, final HttpResponse response) {
        super(message, response);
    }

    /**
     * Initializes a new instance of the ResourceModifiedException class.
     *
     * @param message the exception message or the response content if a message is not available
     * @param response the HTTP response
     * @param value the deserialized response value
     */
    public ResourceModifiedException(final String message, final HttpResponse response, final Object value) {
        super(message, response, value);
    }

    /**
     * Initializes a new instance of the ResourceModifiedException class.
     *
     * @param message the exception message or the response content if a message is not available
     * @param response the HTTP response
     * @param cause the Throwable which caused the creation of this ResourceModifiedException
     */
    public ResourceModifiedException(final String message, final HttpResponse response, final Throwable cause) {
        super(message, response, cause);
    }
}
